summaryrefslogtreecommitdiff
path: root/src/libFLAC/include/private/float.h
diff options
context:
space:
mode:
authorErik de Castro Lopo <erikd@mega-nerd.com>2017-01-14 17:26:39 +1100
committerErik de Castro Lopo <erikd@mega-nerd.com>2017-01-14 17:46:02 +1100
commitc6318e9dd3f7a91f40340911bcf57bf36768910e (patch)
tree19c44a2ef48655e1c81b1779a4d02813b6d0aa78 /src/libFLAC/include/private/float.h
parent55721556161e6ab209f940f5023bc44b4051524a (diff)
downloadflac-c6318e9dd3f7a91f40340911bcf57bf36768910e.tar.gz
Purge usage of `unsigned` type
As pointed out by Ozkan Sezer, on some platforms `int32_t` is actually a typedef for `long` so `unsigned` cannot be used interchangably with `FLAC__uint32`. Fix is to switch from `unsigned` to explicit sized ISO C types defined in <stdint.h>.
Diffstat (limited to 'src/libFLAC/include/private/float.h')
-rw-r--r--src/libFLAC/include/private/float.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/libFLAC/include/private/float.h b/src/libFLAC/include/private/float.h
index 12ece605..cb32da40 100644
--- a/src/libFLAC/include/private/float.h
+++ b/src/libFLAC/include/private/float.h
@@ -81,14 +81,14 @@ extern const FLAC__fixedpoint FLAC__FP_E;
* be < 32 and evenly divisible by 4 (0 is OK but not very precise).
*
* 'precision' roughly limits the number of iterations that are done;
* use (unsigned)(-1) for maximum precision.
*
* If 'x' is less than one -- that is, x < (1<<fracbits) -- then this
* function will punt and return 0.
*
* The return value will also have 'fracbits' fractional bits.
*/
-FLAC__uint32 FLAC__fixedpoint_log2(FLAC__uint32 x, unsigned fracbits, unsigned precision);
+FLAC__uint32 FLAC__fixedpoint_log2(FLAC__uint32 x, uint32_t fracbits, uint32_t precision);
#endif
@@ -81,14 +81,14 @@ extern const FLAC__fixedpoint FLAC__FP_E;
*
* 'precision' roughly limits the number of iterations that are done;
- * use (unsigned)(-1) for maximum precision.
+ * use (uint32_t)(-1) for maximum precision.
*
* If 'x' is less than one -- that is, x < (1<<fracbits) -- then this